@@ -7,7 +7,7 @@ package A1z::HTML5::Template;
 
 sub NAME { my $self = shift; my $NAME; $NAME = "Fast and Easy Web Apps"; return $NAME; }
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 
 
@@ -878,14 +878,20 @@ sub defaults_end
 my %HTML;
 
 %HTML = (
-	-defaultjquery => qq{<!-- -defaultjquery-->\n<!-- jquery-->
-		<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
+	-defaultjquery => qq{\n<!-- -defaultjquery-->
+
+		<!-- jquery-->
+		<script src="https://code.jquery.com/jquery-1.12.4.min.js"></script>
+
 		<!--bootstrap-->
 		<script type="text/javascript" src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
+
 		<!--blueimp gallery-->
 		<script src="https://blueimp.github.io/Gallery/js/jquery.blueimp-gallery.min.js"></script>
+
 		<!-- jquery ui -->
-		<script type="text/javascript" src="https://code.jquery.com/ui/1.11.4/themes/ui-lightness/jquery-ui.css"></script>
+		<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
+
 		<!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
 		<script type="text/javascript" src="https://www.a1z.us/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
 		<script type="text/javascript">
@@ -1097,7 +1103,7 @@ sub head
 		-htmlshim	=> html_shim_respond, 
 		-humanejs  => html_humanejs_css, 
 		-title 		=> "$ENV{SERVER_NAME}" || "", 
-		-cssLinks => "https://blueimp.github.io/Gallery/css/blueimp-gallery.min.css,https://www.a1z.us/A1z/HTML5/Template.css", 
+		-cssLinks => "https://code.jquery.com/ui/1.11.4/themes/ui-lightness/jquery-ui.css,https://blueimp.github.io/Gallery/css/blueimp-gallery.min.css,https://www.a1z.us/A1z/HTML5/Template.css", 
 		-cssCode => "", 
 		-mobilemeta => qq{<meta name="HandheldFriendly" content="true">
 <meta name="viewport" content="width=device-width, initial-scale=1.0">
@@ -1193,7 +1199,7 @@ sub body
 	<script type="text/javascript" src="https://www.a1z.us/js/utils/top-nav-bar.js"></script>
 	<script type="text/javascript">
 	//<-- 
-	fixed_top_navbar('$in{-nbhead}', '$in{-nbpage}', '$in{-nbmenu}', '/support-/sales');
+	fixed_top_navbar('$in{-nbhead}', '$in{-nbpage}', '$in{-nbmenu}', 'support-sales');
 	//-->
 	</script>
 
@@ -1810,7 +1816,7 @@ A1z::HTML5::Template - Fast/easy Web Apps in Perl
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -1886,7 +1892,7 @@ version 0.15
 
 =head2 VERSION
 
-	0.15
+	0.16
 
 =head1 Installation
 
@@ -2049,7 +2055,19 @@ version 0.15
 
 =head1 HTML Hash
 
-	Default HTML used in default_* for internal use only.
+	Hash contains -defaultjquery which is used in body.
+
+	-defaultjquery includes 
+		
+		jquery                1.12.4       from code.jquery
+		jquery ui             1.11.4       
+		bootstrap             3.3.0        from maxcdn
+		blueimp-gallery
+		ie-10 workaround                   from a1z.us
+		
+		functions
+		
+			tabs, dialog, menu, accordion
 
 =head2 html_bootstrap_css 
 
